==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/colorbutton/lang/et.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'et', {
	auto: 'Automaatne',
	bgColorTitle: 'Tausta värv',
	colors: {
		'000': 'Must',
		'800000': 'Kastanpruun',
		'8B4513': 'Sadulapruun',
		'2F4F4F': 'Tume paehall',
		'008080': 'Sinakasroheline',
		'000080': 'Meresinine',
		'4B0082': 'Indigosinine',
		'696969': 'Tumehall',
		B22222: 'Šamottkivi',
		A52A2A: 'Pruun',
		DAA520: 'Kuldkollane',
		'006400': 'Tumeroheline',
		'40E0D0': 'Türkiissinine',
		'0000CD': 'Keskmine sinine',
		'800080': 'Lilla',
		'808080': 'Hall',
		F00: 'Punanae',
		FF8C00: 'Tumeoranž',
		FFD700: 'Kuldne',
		'008000': 'Roheline',
		'0FF': 'Tsüaniidsinine',
		'00F': 'Sinine',
		EE82EE: 'Violetne',
		A9A9A9: 'Tuhm hall',
		FFA07A: 'Hele lõhe',
		FFA500: 'Oranž',
		FFFF00: 'Kollane',
		'00FF00': 'Lubja hall',
		AFEEEE: 'Kahvatu türkiis',
		ADD8E6: 'Helesinine',
		DDA0DD: 'Ploomililla',
		D3D3D3: 'Helehall',
		FFF0F5: 'Lavendlipunane',
		FAEBD7: 'Antiikvalge',
		FFFFE0: 'Helekollane',
		F0FFF0: 'Meloniroheline',
		F0FFFF: 'Taevasinine',
		F0F8FF: 'Beebisinine',
		E6E6FA: 'Lavendel',
		FFF: 'Valge',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Oraanž',
		'E67E22': 'Porgand',
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Silver', // MISSING
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Tume hall'
	},
	more: 'Rohkem värve...',
	panelTitle: 'Värvid',
	textColorTitle: 'Teksti värv'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/colorbutton/lang/et.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'et', {
	auto: 'Automaatne',
	bgColorTitle: 'Tausta värv',
	colors: {
		'000': 'Must',
		'800000': 'Kastanpruun',
		'8B4513': 'Sadulapruun',
		'2F4F4F': 'Tume paehall',
		'008080': 'Sinakasroheline',
		'000080': 'Meresinine',
		'4B0082': 'Indigosinine',
		'696969': 'Tumehall',
		B22222: 'Šamottkivi',
		A52A2A: 'Pruun',
		DAA520: 'Kuldkollane',
		'006400': 'Tumeroheline',
		'40E0D0': 'Türkiissinine',
		'0000CD': 'Keskmine sinine',
		'800080': 'Lilla',
		'808080': 'Hall',
		F00: 'Punanae',
		FF8C00: 'Tumeoranž',
		FFD700: 'Kuldne',
		'008000': 'Roheline',
		'0FF': 'Tsüaniidsinine',
		'00F': 'Sinine',
		EE82EE: 'Violetne',
		A9A9A9: 'Tumehall',
		FFA07A: 'Hele lõhe',
		FFA500: 'Oranž',
		FFFF00: 'Kollane',
		'00FF00': 'Lubja hall',
		AFEEEE: 'Kahvatu türkiis',
		ADD8E6: 'Helesinine',
		DDA0DD: 'Ploomililla',
		D3D3D3: 'Helehall',
		FFF0F5: 'Lavendlipunane',
		FAEBD7: 'Antiikvalge',
		FFFFE0: 'Helekollane',
		F0FFF0: 'Meloniroheline',
		F0FFFF: 'Taevasinine',
		F0F8FF: 'Beebisinine',
		E6E6FA: 'Lavendel',
		FFF: 'Valge',
		'1ABC9C': 'Tugev taevasinine',
		'2ECC71': 'Smaragdroheline',
		'3498DB': 'Kirgas sinine',
		'9B59B6': 'Ametüst',
		'4E5F70': 'Hallikassinine',
		'F1C40F': 'Erkkollane',
		'16A085': 'Tume taevasinine',
		'27AE60': 'Tumeroheline',
		'2980B9': 'Tugev sinine',
		'8E44AD': 'Tumevioletne',
		'2C3E50': 'Hallikassinine',
		'F39C12': 'Oraanž',
		'E67E22': 'Porgand',
		'E74C3C': 'Kahvatu punane',
		'ECF0F1': 'Kirgas hõbedane',
		'95A5A6': 'Hele hallikas taevasinine',
		'DDD': 'Helehall',
		'D35400': 'Kõrvitsavärv',
		'C0392B': 'Tugev punane',
		'BDC3C7': 'Hõbedane',
		'7F8C8D': 'Hallikas taevasinine',
		'999': 'Tume hall'
	},
	more: 'Rohkem värve...',
	panelTitle: 'Värvid',
	textColorTitle: 'Teksti värv'
} );
